@@ -8,7 +8,7 @@ from vulcan_athena.mirandareporting.data_wrangler import data_dict, data_combine
 from vulcan_athena.mirandareporting.fifo_business_logic import calculate_stock_info, calculate_sales, opening_inv_gen, \
     calculate_opening_inventory_actual
 from vulcan_athena.mirandareporting.generic_units_logic import wacgu, get_last_buy_price
-from vulcan_athena.mirandareporting.reporting_framework import dashboard_files_new
+from vulcan_athena.mirandareporting.reporting_framework import dashboard_files_new, inv_dashboard_files
 from vulcan_athena.mirandareporting.setup import STATUS, BUSINESS_LINE, GEN_LIST, FY_YEAR, FY_MAPPER, dataframe_ssp
 
 
@@ -220,11 +220,16 @@ month_dict = {}
 for i in range(1, 13):
     month_dict[calendar.month_name[i]] = i
 
+# Contracted Inventory information
+
+inv_master_df = data_combined(True)
+inv_dict_df, inv_dict_df_future, inv_dict_fy_2022, inv_dict_fy_2023 = data_dict(master_df)
+
 
 # main wrapper function
 
 def main_execute():
-    print('Package run 29 executing...')
+    print('Package run 31 executing...')
 
     # collect the base tables
     base_table_2020, base_table_2020_Inv, base_table_2020_Deal = processor(dict_df, master_df, ssp_df, wacgu_dict,
@@ -237,6 +242,17 @@ def main_execute():
     base_table_2023, base_table_2023_Inv, base_table_2023_Deal = processor(dict_fy_2023, master_df, ssp_df, wacgu_dict,
                                                                            FY_YEAR[3], month_dict)
 
+    # Contracted Inventory information
+    inv_base_table_2020, inv_base_table_2020_Inv, inv_base_table_2020_Deal = processor(inv_dict_df, inv_master_df, ssp_df, wacgu_dict,
+                                                                           FY_YEAR[0], month_dict)
+    inv_base_table_2021, inv_base_table_2021_Inv, inv_base_table_2021_Deal = processor(inv_dict_df_future, inv_master_df, ssp_df,
+                                                                           wacgu_dict,
+                                                                           FY_YEAR[1], month_dict)
+    inv_base_table_2022, inv_base_table_2022_Inv, inv_base_table_2022_Deal = processor(inv_dict_fy_2022, inv_master_df, ssp_df, wacgu_dict,
+                                                                           FY_YEAR[2], month_dict)
+    inv_base_table_2023, inv_base_table_2023_Inv, inv_base_table_2023_Deal = processor(inv_dict_fy_2023, inv_master_df, ssp_df, wacgu_dict,
+                                                                           FY_YEAR[3], month_dict)
+
     # Generate base tables
 
     dashboard_files_new(base_table_2020, base_table_2020_Inv, base_table_2020_Deal, dict_df, FY_YEAR[0])
@@ -244,4 +260,12 @@ def main_execute():
     dashboard_files_new(base_table_2022, base_table_2022_Inv, base_table_2022_Deal, dict_fy_2022, FY_YEAR[2])
     dashboard_files_new(base_table_2023, base_table_2023_Inv, base_table_2023_Deal, dict_fy_2023, FY_YEAR[3])
 
+    # contracted inv base tables
+    print('Running Contracted Inventory code')
+
+    inv_dashboard_files(inv_base_table_2020_Inv, FY_YEAR[0])
+    inv_dashboard_files(inv_base_table_2021_Inv, FY_YEAR[1])
+    inv_dashboard_files(inv_base_table_2022_Inv, FY_YEAR[2])
+    inv_dashboard_files(inv_base_table_2023_Inv, FY_YEAR[3])
+
     return base_table_2020
