@@ -31,7 +31,7 @@ def blob_reader(BLOBNAME, LOCALFILENAME, text_reader=False):
 
 def read_sql(sql_conn):
     conn = pyodbc.connect(sql_conn)
-    sql_query = pd.read_sql_query("SELECT * from Tradebook_Alex", conn)
+    sql_query = pd.read_sql_query("SELECT * from Tradebook", conn)
 
     df = pd.DataFrame(sql_query, columns=['Id', 'TradeDate', 'Direction', 'TradeType', 'Status',
                                           'Name', 'Shares', 'Volume', 'SSP', 'Actual_Sale_Px', 'Instrument',
